Skip to contents

SpatRaster object that can be used a carrying capacity map to initialise data necessary to perform a simulation with the sim function. This map is compatible with n1_small.tif.

Format

SpatRaster object with 15 rows and 10 columns containing integer values 0-100 and NA's indicating unsuitable areas.

Data generated in-house to serve as an example (using spatial autocorrelation).

Examples

system.file("input_maps/K_small.tif", package = "rangr")
#> [1] "C:/Users/katar/AppData/Local/Temp/RtmpUdNKwn/temp_libpath6a642e844808/rangr/input_maps/K_small.tif"